netapp_ontap.models.data_engine_entity_attributes API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_entity_attributes`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineEntityAttributesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineEntityAttributes object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `content: List[DataEngineEntityAttributesContent] GET POST PATCH`

    The content field of the data_engine_entity_attributes.

  `custom: List[DataEngineEntityAttributesCustom] GET POST PATCH`

    The custom field of the data_engine_entity_attributes.

  `extended: List[DataEngineEntityAttributesExtended] GET POST PATCH`

    The extended field of the data_engine_entity_attributes.

  `system: List[DataEngineEntityAttributesSystem] GET POST PATCH`

    The system field of the data_engine_entity_attributes.